<?php

include('../../path.php');

require_once(ROOT_CONFIG);



    class cartera_contrasenas

    {

        public function insert_cartera_contrasenas($Id_Fk_Categoria, $Categoria, $Nombre_Registro, $Nombre_Servicio, $Url_Acceso, $Host_O_Ip, $Usuario_Acceso, $Contrasena_Acceso, $Correo_Relacionado, $Telefono_Soporte, $Tags, $Notas, $Es_Favorito, $Estatus, $Registro, $Fecha_Registro, $Modifico, $Fecha_Modificacion)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="INSERT INTO cartera_contrasenas(Id_Fk_Categoria, Categoria, Nombre_Registro, Nombre_Servicio, Url_Acceso, Host_O_Ip, Usuario_Acceso, Contrasena_Acceso, Correo_Relacionado, Telefono_Soporte, Notas) VALUES ('$Id_Fk_Categoria', '$Categoria', '$Nombre_Registro', '$Nombre_Servicio', '$Url_Acceso', '$Host_O_Ip', '$Usuario_Acceso', '$Contrasena_Acceso', '$Correo_Relacionado', '$Telefono_Soporte', '$Notas') ";

            $conexion->query($consulta);

            $whatsmyid=$conexion->insert_id;

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='registrar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $whatsmyid;

        }



        public function get_cartera_contrasenas($_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                //$consulta="SELECT *,  count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk ORDER BY Id_Cartera DESC";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk";

            }else{

                //$consulta="SELECT *,  count(*) as numregis FROM cartera_contrasenas ORDER BY Id_Cartera DESC";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_cartera_contrasenaspg($inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk ORDER BY Id_Cartera DESC";

            }else{

                $consulta="SELECT * FROM cartera_contrasenas ORDER BY Id_Cartera DESC";

            }

            

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_cartera_contrasenas($Id_Cartera, $Id_Fk_Categoria, $Categoria, $Nombre_Registro, $Nombre_Servicio, $Url_Acceso, $Host_O_Ip, $Usuario_Acceso, $Contrasena_Acceso, $Correo_Relacionado, $Telefono_Soporte, $Tags, $Notas, $Es_Favorito, $Estatus, $Registro, $Fecha_Registro, $Modifico, $Fecha_Modificacion)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE cartera_contrasenas SET Id_Cartera='$Id_Cartera', Id_Fk_Categoria='$Id_Fk_Categoria', Categoria='$Categoria', Nombre_Registro='$Nombre_Registro', Nombre_Servicio='$Nombre_Servicio', Url_Acceso='$Url_Acceso', Host_O_Ip='$Host_O_Ip', Usuario_Acceso='$Usuario_Acceso', Contrasena_Acceso='$Contrasena_Acceso', Correo_Relacionado='$Correo_Relacionado', Telefono_Soporte='$Telefono_Soporte', Notas='$Notas' WHERE Id_Cartera = '$Id_Cartera'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;

        }



        public function delete_cartera_contrasenas($Id_Cartera)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="DELETE FROM cartera_contrasenas WHERE Id_Cartera='$Id_Cartera'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='eliminar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;

        }



        //Funciones adicionales.

        public function getorderby_cartera_contrasenas($Nombre,$Orderby,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                //$consulta="SELECT *,  count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk ORDER BY $Nombre $Orderby";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk";

            }else{

                //$consulta="SELECT *,  count(*) as numregis FROM cartera_contrasenas ORDER BY $Nombre $Orderby";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getorderby_cartera_contrasenaspg($Nombre,$Orderby,$inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk ORDER BY $Nombre $Orderby";

            }else{

                $consulta="SELECT * FROM cartera_contrasenas ORDER BY $Nombre $Orderby";

            }

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function getbyid_cartera_contrasenas($Id_Cartera)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM cartera_contrasenas WHERE Id_Cartera='$Id_Cartera'";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function get_cartera_contrasenas_paginador_frm()

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM cartera_contrasenas";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function search_cartera_contrasenas($Buscar,$_Clausula_Fk,$_IdFk)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT *, count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk AND (Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%') ORDER BY Id_Cartera DESC";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk AND (Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%')";

            }else{

                //$consulta="SELECT *, count(*) as numregis FROM cartera_contrasenas WHERE Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%' ORDER BY Id_Cartera DESC";

                $consulta="SELECT count(*) as numregis FROM cartera_contrasenas WHERE Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%'";  

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='busco:'.$Buscar;

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_consultas($_Tabla,$_Evento_Log,$_Consulta);

            return $Array_adapter;

        }



        public function search_cartera_contrasenaspg($Buscar,$inicio,$TAMANO_PAGINA,$_Clausula_Fk,$_IdFk)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            if($_Clausula_Fk!='' && $_IdFk!=''){

                $consulta="SELECT * FROM cartera_contrasenas WHERE $_Clausula_Fk=$_IdFk AND (Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%') ORDER BY Id_Cartera DESC";

            }else{

                $consulta="SELECT * FROM cartera_contrasenas WHERE Id_Cartera LIKE '%$Buscar%' || Id_Fk_Categoria LIKE '%$Buscar%' || Categoria LIKE '%$Buscar%' || Nombre_Registro LIKE '%$Buscar%' || Nombre_Servicio LIKE '%$Buscar%' || Url_Acceso LIKE '%$Buscar%' || Host_O_Ip LIKE '%$Buscar%' || Usuario_Acceso LIKE '%$Buscar%' || Contrasena_Acceso LIKE '%$Buscar%' || Correo_Relacionado LIKE '%$Buscar%' || Telefono_Soporte LIKE '%$Buscar%' || Tags LIKE '%$Buscar%' || Notas LIKE '%$Buscar%' || Es_Favorito LIKE '%$Buscar%' || Estatus LIKE '%$Buscar%' || Registro LIKE '%$Buscar%' || Fecha_Registro LIKE '%$Buscar%' || Modifico LIKE '%$Buscar%' || Fecha_Modificacion LIKE '%$Buscar%' ORDER BY Id_Cartera DESC";

            }

            if ($TAMANO_PAGINA != "Todos") {

                $consulta .= " LIMIT $inicio, $TAMANO_PAGINA";

            }

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }



        public function searchbyparameter_cartera_contrasenas($Parametro,$Buscar)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="SELECT * FROM cartera_contrasenas WHERE $Parametro LIKE '%$Buscar%' ORDER BY Id_Cartera DESC";

            $Array_adapter=$conexion->query($consulta);

            $conexion->close();

            return $Array_adapter;

        }

  

        public function execute_cartera_contrasenas($query)

        {

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $Array_adapter=$conexion->query($query);

            $conexion->close();

            return $Array_adapter;

        }



        public function update_field_cartera_contrasenas($Field,$Value,$Id_Cartera)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Valueinto=strtoupper($Value);

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE cartera_contrasenas SET $Field='$Valueinto' WHERE Id_Cartera= '$Id_Cartera'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;                          

        }



        public function update_field_front_cartera_contrasenas($Field,$Value,$Id_Cartera)

        {

            require_once('../../log/controller/log.php');

            $Obj_log = new log();

            $Odbj_conexion = new odbconexion;

            $conexion=$Odbj_conexion->openconection();

            $consulta="UPDATE cartera_contrasenas SET $Field='$Value' WHERE Id_Cartera= '$Id_Cartera'";

            $conexion->query($consulta);

            $rowaffected=$conexion->affected_rows;

            $conexion->close();

            $_Tabla='cartera_contrasenas';

            $_Evento_Log='editar';

            $_Consulta = '"'.$consulta.'"';

            $Obj_log->insert_log_crud($_Tabla,$_Evento_Log,$_Consulta);

            return $rowaffected;                          

        }



}



?>